@@ -13,20 +13,18 @@ use Params::Validate qw( :all );
 use Readonly;
 #use Smart::Comments;
 
-=encoding utf-8
-
 =head1 NAME
 
 WebService::Smartling - The great new WebService::Smartling!
 
 =head1 VERSION
 
-Version 0.0.4
+Version 0.01
 
 =cut
 
 use version;
-our $VERSION = version->declare("v0.0.4");
+our $VERSION = version->declare("v0.01");
 
 =head1 SYNOPSIS
 
@@ -474,7 +472,8 @@ sub fileRename {
 
 =head2 fileStatus(I<%params>)
 
-Returns the translation status for the provided file and locale.
+Uploads original source content to Smartling (5MB limit), not translated 
+files (other than importing .tmx files).
 
 Refer to 
 L<https://docs.smartling.com/display/docs/Files+API#FilesAPI-/file/status%28GET%29>
@@ -708,7 +707,7 @@ sub projectLocaleList {
 
 =head1 AUTHOR
 
-Matthew Cox, C<< <mcox at cpan.org> >>
+Matthew Cox, C<< <coxmat+cpan at gmail.com> >>
 
 =head1 BUGS
 
@@ -793,4 +792,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =cut
 
 1; # End of WebService::Smartling
-__END__
+__END__
\ No newline at end of file
